# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import option_type_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_option__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/timeofday.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/option_type.proto\"\xb1\x10\n\x11StaticDataRequest\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x31\n\x05start\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\x12\x1c\n\tbloomberg\x18\x04 \x01(\tR\tbloomberg\x12\x10\n\x03\x63ik\x18\x05 \x01(\tR\x03\x63ik\x12\x1e\n\ncomponents\x18\x06 \x01(\tR\ncomponents\x12\x1a\n\x08\x63ontract\x18\x07 \x01(\tR\x08\x63ontract\x12\x1a\n\x08\x63urrency\x18\x08 \x01(\tR\x08\x63urrency\x12%\n\x0equote_currency\x18\t \x01(\tR\rquoteCurrency\x12\x14\n\x05\x63usip\x18\n \x01(\tR\x05\x63usip\x12 \n\x0b\x64\x65scription\x18\x0b \x01(\tR\x0b\x64\x65scription\x12\x1a\n\x08\x65xchange\x18\x0c \x01(\tR\x08\x65xchange\x12\x12\n\x04\x66igi\x18\r \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x0e \x01(\tR\x05\x66igic\x12\x14\n\x05index\x18\x0f \x01(\tR\x05index\x12\x12\n\x04isin\x18\x10 \x01(\tR\x04isin\x12\x12\n\x04name\x18\x13 \x01(\tR\x04name\x12\x18\n\x07primary\x18\x15 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x16 \x01(\tR\toperating\x12\x16\n\x06sector\x18\x17 \x01(\tR\x06sector\x12\x14\n\x05sedol\x18\x18 \x01(\tR\x05sedol\x12\x16\n\x06ticker\x18\x19 \x01(\tR\x06ticker\x12\x1e\n\nunderlying\x18\x1a \x01(\tR\nunderlying\x12&\n\x0e\x63lassification\x18\x1b \x01(\tR\x0e\x63lassification\x12U\n\x08maturity\x18\x1c \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.StaticDataDateR\x08maturity\x12\x63\n\x0e\x63\x61pitalization\x18\x1d \x01(\x0b\x32;.systemathics.apis.services.static_data.v1.StaticDataDoubleR\x0e\x63\x61pitalization\x12Q\n\x06\x65xpiry\x18\x1e \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.StaticDataDateR\x06\x65xpiry\x12M\n\x0boption_type\x18\x1f \x01(\x0e\x32,.systemathics.apis.type.shared.v1.OptionTypeR\noptionType\x12\\\n\rexercise_type\x18  \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.ExerciseTypeR\x0c\x65xerciseType\x12!\n\x0cpayment_rank\x18\" \x01(\tR\x0bpaymentRank\x12\x16\n\x06issuer\x18# \x01(\tR\x06issuer\x12\x1f\n\x0b\x63oupon_type\x18$ \x01(\tR\ncouponType\x12\x18\n\x07\x63ountry\x18% \x01(\tR\x07\x63ountry\x12N\n\x05month\x18& \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.StaticDataIntR\x05month\x12L\n\x04year\x18\' \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.StaticDataIntR\x04year\x12S\n\x06strike\x18( \x01(\x0b\x32;.systemathics.apis.services.static_data.v1.StaticDataDoubleR\x06strike\x12/\n\x14\x63\x64s_index_sub_family\x18) \x01(\tR\x11\x63\x64sIndexSubFamily\x12\x14\n\x05tenor\x18* \x01(\tR\x05tenor\x12\x62\n\x10\x63\x64s_index_series\x18, \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.StaticDataIntR\x0e\x63\x64sIndexSeries\x12\x64\n\x11\x63\x64s_index_version\x18- \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.StaticDataIntR\x0f\x63\x64sIndexVersion\x12\x34\n\x17\x63\x64s_index_red_pair_code\x18. \x01(\tR\x13\x63\x64sIndexRedPairCode\x12\\\n\rswaption_type\x18/ \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.SwaptionTypeR\x0cswaptionType\x12J\n\x14\x63\x64s_index_on_the_run\x18\x30 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63\x64sIndexOnTheRun\x12#\n\rmarket_status\x18\x32 \x01(\tR\x0cmarketStatus\"\xa1\x01\n\x1eStaticDataByIdentifiersRequest\x12N\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\x0bidentifiers\x12/\n\nas_of_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x08\x61sOfDate\"\x9c\x01\n\x0eStaticDataDate\x12)\n\x05\x65xact\x18\x01 \x01(\x0b\x32\x11.google.type.DateH\x00R\x05\x65xact\x12V\n\x05range\x18\x02 \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeH\x00R\x05rangeB\x07\n\x05oneof\"\x8b\x01\n\x13StaticDataDateRange\x12.\n\tless_than\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x08lessThan\x12\x44\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x12greaterOrEqualThan\"\x8d\x01\n\x10StaticDataDouble\x12\x16\n\x05\x65xact\x18\x01 \x01(\x01H\x00R\x05\x65xact\x12X\n\x05range\x18\x02 \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeH\x00R\x05rangeB\x07\n\x05oneof\"\xa3\x01\n\x15StaticDataDoubleRange\x12\x39\n\tless_than\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x08lessThan\x12O\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x12greaterOrEqualThan\"\x87\x01\n\rStaticDataInt\x12\x16\n\x05\x65xact\x18\x01 \x01(\x03H\x00R\x05\x65xact\x12U\n\x05range\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.static_data.v1.StaticDataIntRangeH\x00R\x05rangeB\x07\n\x05oneof\"\x9e\x01\n\x12StaticDataIntRange\x12\x38\n\tless_than\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x08lessThan\x12N\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12greaterOrEqualThan\"\xc5\x07\n\x12StaticDataResponse\x12Q\n\x06\x66uture\x18\x01 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.FutureResponseR\x06\x66uture\x12Q\n\x06\x65quity\x18\x02 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.EquityResponseR\x06\x65quity\x12H\n\x03\x65tf\x18\x03 \x01(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EtfResponseR\x03\x65tf\x12N\n\x05index\x18\x04 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.IndexResponseR\x05index\x12N\n\x05\x66orex\x18\x06 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.ForexResponseR\x05\x66orex\x12Q\n\x06option\x18\x07 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.OptionResponseR\x06option\x12K\n\x04\x62ond\x18\x08 \x01(\x0b\x32\x37.systemathics.apis.services.static_data.v1.BondResponseR\x04\x62ond\x12H\n\x03\x63\x64s\x18\t \x01(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CdsResponseR\x03\x63\x64s\x12X\n\tcds_index\x18\n \x01(\x0b\x32;.systemathics.apis.services.static_data.v1.CdsIndexResponseR\x08\x63\x64sIndex\x12n\n\x11\x63\x64s_index_tranche\x18\x0b \x01(\x0b\x32\x42.systemathics.apis.services.static_data.v1.CdsIndexTrancheResponseR\x0f\x63\x64sIndexTranche\x12k\n\x10\x63\x64s_index_option\x18\x0c \x01(\x0b\x32\x41.systemathics.apis.services.static_data.v1.CdsIndexOptionResponseR\x0e\x63\x64sIndexOption\"\x91\x01\n\x16\x43\x64sIndexOptionResponse\x12V\n\x06\x61ssets\x18\x01 \x03(\x0b\x32>.systemathics.apis.services.static_data.v1.CdsIndexOptionEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\xcc\x03\n\x13\x43\x64sIndexOptionEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x61\x63tive\x18\x02 \x01(\x08R\x06\x61\x63tive\x12\x1a\n\x08\x63urrency\x18\x03 \x01(\tR\x08\x63urrency\x12\x1e\n\nunderlying\x18\x04 \x01(\tR\nunderlying\x12\x16\n\x06strike\x18\x05 \x01(\x01R\x06strike\x12)\n\x06\x65xpiry\x18\x06 \x01(\x0b\x32\x11.google.type.DateR\x06\x65xpiry\x12\\\n\rswaption_type\x18\x07 \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.SwaptionTypeR\x0cswaptionType\x12\x18\n\x07version\x18\x08 \x01(\x05R\x07version\x12\x12\n\x04\x66igi\x18\t \x01(\tR\x04\x66igi\x12\x1a\n\x08\x63\x61lendar\x18\n \x01(\tR\x08\x63\x61lendar\x12(\n\x10otc_streaming_id\x18\x0b \x01(\tR\x0eotcStreamingId\"}\n\x0c\x42ondResponse\x12L\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.services.static_data.v1.BondEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"{\n\x0b\x43\x64sResponse\x12K\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.CdsEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x85\x01\n\x10\x43\x64sIndexResponse\x12P\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x38.systemathics.apis.services.static_data.v1.CdsIndexEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x93\x01\n\x17\x43\x64sIndexTrancheResponse\x12W\n\x06\x61ssets\x18\x01 \x03(\x0b\x32?.systemathics.apis.services.static_data.v1.CdsIndexTrancheEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x45quityResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"{\n\x0b\x45tfResponse\x12K\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.EtfEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x7f\n\rForexResponse\x12M\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.ForexEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x46utureResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x7f\n\rIndexResponse\x12M\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.IndexEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0eOptionResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.OptionEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x98\x19\n\x0b\x45quityEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x18\n\x07\x63ountry\x18\x02 \x01(\tR\x07\x63ountry\x12\x1a\n\x08\x63urrency\x18\x03 \x01(\tR\x08\x63urrency\x12\x37\n\x18parse_keyable_des_source\x18\x04 \x01(\tR\x15parseKeyableDesSource\x12\x12\n\x04\x66igi\x18\x05 \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x06 \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x07 \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x08 \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\t \x01(\tR\x05sedol\x12#\n\rmarket_status\x18\n \x01(\tR\x0cmarketStatus\x12&\n\x0e\x63lassification\x18\x0b \x01(\tR\x0e\x63lassification\x12*\n\x11icb_subsector_num\x18\x0c \x01(\tR\x0ficbSubsectorNum\x12&\n\x0e\x63\x61pitalization\x18\r \x01(\x01R\x0e\x63\x61pitalization\x12)\n\x11px_trade_lot_size\x18\x0e \x01(\x01R\x0epxTradeLotSize\x12[\n\x0ftick_size_table\x18\x0f \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\rtickSizeTable\x12$\n\x0eprev_close_val\x18\x10 \x01(\x01R\x0cprevCloseVal\x12\x45\n\x15previous_trading_date\x18\x11 \x01(\x0b\x32\x11.google.type.DateR\x13previousTradingDate\x12\x32\n\x15previous_total_volume\x18\x12 \x01(\x03R\x13previousTotalVolume\x12\x14\n\x05index\x18\x15 \x03(\tR\x05index\x12\'\n\x0f\x63ompany_address\x18\x16 \x03(\tR\x0e\x63ompanyAddress\x12,\n\x12\x63ompany_tel_number\x18\x17 \x01(\tR\x10\x63ompanyTelNumber\x12(\n\x10ir_email_address\x18\x18 \x01(\tR\x0eirEmailAddress\x12.\n\x13\x63ompany_web_address\x18\x19 \x01(\tR\x11\x63ompanyWebAddress\x12r\n\x1ctop20_holders_public_filings\x18\x1a \x03(\x0b\x32\x31.systemathics.apis.services.static_data.v1.HolderR\x19top20HoldersPublicFilings\x12 \n\x0b\x64\x65scription\x18\x1b \x01(\tR\x0b\x64\x65scription\x12*\n\x11gics_sub_industry\x18\x1c \x01(\tR\x0fgicsSubIndustry\x12@\n\x1d\x62ics_level4_sub_industry_code\x18\x1d \x01(\tR\x19\x62icsLevel4SubIndustryCode\x12 \n\x0c\x65qy_sic_code\x18\x1e \x01(\tR\neqySicCode\x12+\n\x12\x65qy_prim_exch_shrt\x18\x1f \x01(\tR\x0f\x65qyPrimExchShrt\x12(\n\x10gics_sector_name\x18  \x01(\tR\x0egicsSectorName\x12\'\n\x0findustry_sector\x18! \x01(\tR\x0eindustrySector\x12%\n\x0eindustry_group\x18\" \x01(\tR\rindustryGroup\x12+\n\x11industry_subgroup\x18# \x01(\tR\x10industrySubgroup\x12-\n\x12\x64ividend_frequency\x18$ \x01(\tR\x11\x64ividendFrequency\x12+\n\x11\x64ividend_currency\x18% \x01(\tR\x10\x64ividendCurrency\x12*\n\x11\x65qy_fund_currency\x18& \x01(\tR\x0f\x65qyFundCurrency\x12\x30\n\x14\x65qy_option_available\x18\' \x01(\x08R\x12\x65qyOptionAvailable\x12@\n\x13\x65qy_initial_po_date\x18( \x01(\x0b\x32\x11.google.type.DateR\x10\x65qyInitialPoDate\x12=\n\x1b\x65qy_shares_outstanding_real\x18) \x01(\x01R\x18\x65qySharesOutstandingReal\x12+\n\x12\x65qy_free_float_pct\x18* \x01(\x01R\x0f\x65qyFreeFloatPct\x12&\n\x0f\x65qy_fund_ticker\x18+ \x01(\tR\reqyFundTicker\x12#\n\rsecurity_type\x18, \x01(\tR\x0csecurityType\x12\x34\n\x16parent_ticker_exchange\x18- \x01(\tR\x14parentTickerExchange\x12;\n\x1ault_parent_ticker_exchange\x18. \x01(\tR\x17ultParentTickerExchange\x12\x30\n\x14\x61\x64r_underlier_ticker\x18/ \x01(\tR\x12\x61\x64rUnderlierTicker\x12+\n\x12\x61\x64r_shares_per_adr\x18\x30 \x01(\x01R\x0f\x61\x64rSharesPerAdr\x12\x16\n\x06sedol2\x18\x31 \x01(\tR\x06sedol2\x12\x10\n\x03\x63ik\x18\x32 \x01(\tR\x03\x63ik\x12\x1b\n\tfeed_eid1\x18\x33 \x01(\tR\x08\x66\x65\x65\x64\x45id1\x12*\n\x11\x66\x65\x65\x64_delayed_eid1\x18\x34 \x01(\tR\x0f\x66\x65\x65\x64\x44\x65layedEid1\x12\x1b\n\tfeed_eid2\x18\x35 \x01(\tR\x08\x66\x65\x65\x64\x45id2\x12\x1b\n\tfeed_eid3\x18\x36 \x01(\tR\x08\x66\x65\x65\x64\x45id3\x12\x1b\n\tfeed_eid4\x18\x37 \x01(\tR\x08\x66\x65\x65\x64\x45id4\x12\x38\n\x18\x63ompany_description_bulk\x18\x38 \x03(\tR\x16\x63ompanyDescriptionBulk\x12\x30\n\x14icb_supersector_name\x18\x39 \x01(\tR\x12icbSupersectorName\x12\x65\n\x14\x64ividend_history_all\x18: \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.DividendR\x12\x64ividendHistoryAll\x12\x32\n\x15parent_company_ticker\x18; \x01(\tR\x13parentCompanyTicker\x12:\n\x19market_sector_description\x18< \x01(\tR\x17marketSectorDescription\x12\x1c\n\toperating\x18= \x01(\tR\toperating\x12\x18\n\x07primary\x18> \x01(\tR\x07primary\x12\x16\n\x06ticker\x18@ \x01(\tR\x06ticker\x12\x12\n\x04name\x18\x41 \x01(\tR\x04name\x12\xa5\x01\n0earnings_announcement_date_time_history_with_eps\x18\x42 \x03(\x0b\x32?.systemathics.apis.services.static_data.v1.EarningsAnnouncementR*earningsAnnouncementDateTimeHistoryWithEps\x12\x8f\x01\n!best_analyst_recommendations_bulk\x18\x43 \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.BestAnalystRecommendationR\x1e\x62\x65stAnalystRecommendationsBulk\x12\x85\x01\n top_analyst_performance_rank_trr\x18\x44 \x03(\x0b\x32=.systemathics.apis.services.static_data.v1.AnalystPerformanceR\x1ctopAnalystPerformanceRankTrr\x12\x1d\n\nlisted_mic\x18\x45 \x03(\tR\tlistedMic\"\x93\x15\n\x08\x45tfEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x18\n\x07primary\x18\x03 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x04 \x01(\tR\toperating\x12\x1d\n\nlisted_mic\x18\x05 \x03(\tR\tlistedMic\x12 \n\x0b\x64\x65scription\x18\x06 \x01(\tR\x0b\x64\x65scription\x12\'\n\x0findustry_sector\x18\x07 \x01(\tR\x0eindustrySector\x12%\n\x0eindustry_group\x18\x08 \x01(\tR\rindustryGroup\x12\x16\n\x06issuer\x18\t \x01(\tR\x06issuer\x12\'\n\x0f\x63ompany_address\x18\n \x03(\tR\x0e\x63ompanyAddress\x12,\n\x12\x63ompany_tel_number\x18\x0b \x01(\tR\x10\x63ompanyTelNumber\x12(\n\x10ir_email_address\x18\x0c \x01(\tR\x0eirEmailAddress\x12.\n\x13\x63ompany_web_address\x18\r \x01(\tR\x11\x63ompanyWebAddress\x12r\n\x1ctop20_holders_public_filings\x18\x0e \x03(\x0b\x32\x31.systemathics.apis.services.static_data.v1.HolderR\x19top20HoldersPublicFilings\x12;\n\x10\x66und_incept_date\x18\x0f \x01(\x0b\x32\x11.google.type.DateR\x0e\x66undInceptDate\x12&\n\x0e\x63\x61pitalization\x18\x10 \x01(\x01R\x0e\x63\x61pitalization\x12&\n\x0e\x63lassification\x18\x11 \x01(\tR\x0e\x63lassification\x12#\n\rsecurity_type\x18\x12 \x01(\tR\x0csecurityType\x12\x18\n\x07\x63ountry\x18\x13 \x01(\tR\x07\x63ountry\x12:\n\x19market_sector_description\x18\x14 \x01(\tR\x17marketSectorDescription\x12\x16\n\x06ticker\x18\x15 \x01(\tR\x06ticker\x12\x12\n\x04\x66igi\x18\x16 \x01(\tR\x04\x66igi\x12\x1d\n\nshort_name\x18\x17 \x01(\tR\tshortName\x12\x1a\n\x08\x63urrency\x18\x18 \x01(\tR\x08\x63urrency\x12\x36\n\x17\x65quity_option_available\x18\x19 \x01(\x08R\x15\x65quityOptionAvailable\x12\x33\n\x16\x66und_asset_class_focus\x18\x1a \x01(\tR\x13\x66undAssetClassFocus\x12$\n\x0e\x66und_geo_focus\x18\x1b \x01(\tR\x0c\x66undGeoFocus\x12+\n\x11industry_subgroup\x18\x1c \x01(\tR\x10industrySubgroup\x12\x31\n\x14replication_strategy\x18\x1d \x01(\tR\x13replicationStrategy\x12,\n\x12\x66und_leverage_type\x18\x1e \x01(\tR\x10\x66undLeverageType\x12#\n\rfund_leverage\x18\x1f \x01(\tR\x0c\x66undLeverage\x12\x30\n\x14\x66und_leverage_amount\x18  \x01(\tR\x12\x66undLeverageAmount\x12>\n\x1bindex_weighting_methodology\x18! \x01(\tR\x19indexWeightingMethodology\x12\x33\n\x15rebalancing_frequency\x18\" \x01(\tR\x14rebalancingFrequency\x12#\n\rmarket_status\x18# \x01(\tR\x0cmarketStatus\x12\x12\n\x04isin\x18$ \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18% \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18& \x01(\tR\x05sedol\x12*\n\x11px_scaling_factor\x18\' \x01(\x01R\x0fpxScalingFactor\x12\x32\n\x15previous_total_volume\x18( \x01(\x01R\x13previousTotalVolume\x12$\n\x0eprev_close_val\x18) \x01(\x01R\x0cprevCloseVal\x12\x1f\n\x0bpx_volume1d\x18* \x01(\x01R\npxVolume1d\x12\x45\n\x15previous_trading_date\x18+ \x01(\x0b\x32\x11.google.type.DateR\x13previousTradingDate\x12&\n\x0ftick_size_table\x18/ \x01(\tR\rtickSizeTable\x12\x39\n\x1apx_disp_format_min_num_dec\x18\x30 \x01(\x05R\x15pxDispFormatMinNumDec\x12$\n\x0elong_comp_name\x18\x31 \x01(\tR\x0clongCompName\x12&\n\x0f\x66und_assets_usd\x18\x32 \x01(\x01R\rfundAssetsUsd\x12<\n\x1b\x65qy_prim_security_prim_exch\x18\x33 \x01(\tR\x17\x65qyPrimSecurityPrimExch\x12;\n\x10price_close_date\x18\x34 \x01(\x0b\x32\x11.google.type.DateR\x0epriceCloseDate\x12.\n\x13\x66und_industry_focus\x18\x35 \x01(\tR\x11\x66undIndustryFocus\x12\x1b\n\tfeed_eid1\x18\x36 \x01(\tR\x08\x66\x65\x65\x64\x45id1\x12*\n\x11\x66\x65\x65\x64_delayed_eid1\x18\x37 \x01(\tR\x0f\x66\x65\x65\x64\x44\x65layedEid1\x12\x1b\n\tfeed_eid2\x18\x38 \x01(\tR\x08\x66\x65\x65\x64\x45id2\x12\x1b\n\tfeed_eid3\x18\x39 \x01(\tR\x08\x66\x65\x65\x64\x45id3\x12\x1b\n\tfeed_eid4\x18: \x01(\tR\x08\x66\x65\x65\x64\x45id4\x12%\n\x0f\x65qy_sh_out_real\x18; \x01(\x01R\x0c\x65qyShOutReal\x12\x19\n\x08\x64vd_freq\x18< \x01(\tR\x07\x64vdFreq\x12\x1b\n\tdvd_crncy\x18= \x01(\tR\x08\x64vdCrncy\x12 \n\x0c\x64vd_typ_last\x18> \x01(\tR\ndvdTypLast\x12#\n\rfund_strategy\x18? \x01(\tR\x0c\x66undStrategy\x12r\n\x1c\x64vd_hist_all_with_amt_status\x18@ \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.DividendR\x17\x64vdHistAllWithAmtStatus\x12=\n\x1b\x65tf_underlierl_index_ticker\x18\x41 \x01(\tR\x18\x65tfUnderlierlIndexTicker\x12\x1b\n\tfund_type\x18\x42 \x01(\tR\x08\x66undType\"\xa5\x1e\n\x0b\x46utureEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x1a\n\x08\x63ontract\x18\x02 \x01(\tR\x08\x63ontract\x12\x14\n\x05month\x18\x03 \x01(\x05R\x05month\x12\x12\n\x04year\x18\x04 \x01(\x05R\x04year\x12\x44\n\x0e\x63lassification\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0e\x63lassification\x12?\n\x0c\x63\x61sh_settled\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x63\x61shSettled\x12L\n\x13\x63\x64r_settlement_code\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11\x63\x64rSettlementCode\x12\x36\n\x07\x63ountry\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x63ountry\x12=\n\x0b\x63ountry_iso\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\ncountryIso\x12\x38\n\x08\x63urrency\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63urrency\x12\x41\n\rexchange_code\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0c\x65xchangeCode\x12\x41\n\rmarket_status\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cmarketStatus\x12^\n\x1d\x66\x65\x65\x64_delayed_entitlement_id_1\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x19\x66\x65\x65\x64\x44\x65layedEntitlementId1\x12O\n\x15\x66\x65\x65\x64_entitlement_id_1\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x12\x66\x65\x65\x64\x45ntitlementId1\x12O\n\x15\x66\x65\x65\x64_entitlement_id_2\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x12\x66\x65\x65\x64\x45ntitlementId2\x12O\n\x15\x66\x65\x65\x64_entitlement_id_3\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x12\x66\x65\x65\x64\x45ntitlementId3\x12G\n\x10\x66utures_category\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0f\x66uturesCategory\x12#\n\rfutures_chain\x18\x12 \x03(\tR\x0c\x66uturesChain\x12\x41\n\rcontract_size\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0c\x63ontractSize\x12\x41\n\x13\x66irst_delivery_date\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x11\x66irstDeliveryDate\x12?\n\x12last_delivery_date\x18\x15 \x01(\x0b\x32\x11.google.type.DateR\x10lastDeliveryDate\x12J\n\x12long_exchange_name\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x10longExchangeName\x12L\n\x13short_exchange_name\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11shortExchangeName\x12;\n\x10\x66irst_trade_date\x18\x18 \x01(\x0b\x32\x11.google.type.DateR\x0e\x66irstTradeDate\x12L\n\x13month_year_maturity\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11monthYearMaturity\x12=\n\x11\x66irst_notice_date\x18\x1a \x01(\x0b\x32\x11.google.type.DateR\x0f\x66irstNoticeDate\x12I\n\x11options_available\x18\x1b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x10optionsAvailable\x12\x39\n\ttick_size\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x08tickSize\x12;\n\ntick_value\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\ttickValue\x12\x44\n\x0fone_point_value\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\ronePointValue\x12\x30\n\x04\x66igi\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04\x66igi\x12]\n\x1cultimate_parent_company_name\x18  \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x19ultimateParentCompanyName\x12\x32\n\x05\x63usip\x18! \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x63usip\x12\x32\n\x05sedol\x18\" \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sedol\x12\x30\n\x04isin\x18# \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04isin\x12P\n\x15local_exchange_symbol\x18$ \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x13localExchangeSymbol\x12N\n\x14primary_exchange_mic\x18% \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x12primaryExchangeMic\x12-\n\x08maturity\x18& \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12X\n\x19market_sector_description\x18\' \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x17marketSectorDescription\x12.\n\x03mic\x18( \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x03mic\x12\x30\n\x04name\x18) \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04name\x12U\n\x17parskeyable_description\x18* \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x16parskeyableDescription\x12\x62\n\x1eparskeyable_description_source\x18+ \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x1cparskeyableDescriptionSource\x12O\n\x15previous_total_volume\x18, \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13previousTotalVolume\x12\x45\n\x15previous_trading_date\x18- \x01(\x0b\x32\x11.google.type.DateR\x13previousTradingDate\x12N\n\x14previous_close_value\x18. \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x12previousCloseValue\x12N\n\x14price_scaling_factor\x18/ \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x12priceScalingFactor\x12I\n\x12volume_one_day_ago\x18\x30 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0fvolumeOneDayAgo\x12=\n\x0bquote_units\x18\x31 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nquoteUnits\x12O\n\x14security_description\x18\x32 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x13securityDescription\x12\x41\n\rsecurity_type\x18\x33 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0csecurityType\x12;\n\nshort_name\x18\x34 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tshortName\x12\x34\n\x06ticker\x18\x35 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06ticker\x12[\n\x0ftick_size_table\x18\x36 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\rtickSizeTable\x12K\n\x16trading_day_start_time\x18\x37 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x13tradingDayStartTime\x12G\n\x14trading_day_end_time\x18\x38 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x11tradingDayEndTime\x12R\n\x16underlying_spot_ticker\x18\x39 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x14underlyingSpotTicker\"\xe9\x0c\n\nIndexEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12\\\n\x07mapping\x18\x16 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.IndexEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1a\n\x08\x63\x61tegory\x18! \x01(\tR\x08\x63\x61tegory\x12 \n\x0bmethodology\x18\" \x01(\tR\x0bmethodology\x12\x16\n\x06issuer\x18# \x01(\tR\x06issuer\x12\x30\n\nissue_date\x18$ \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12V\n\tfrequency\x18% \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12\x65\n\ncomponents\x18& \x03(\x0b\x32\x45.systemathics.apis.services.static_data.v1.IndexEntry.ComponentsEntryR\ncomponents\x12)\n\x10\x63omponents_count\x18\' \x01(\x03R\x0f\x63omponentsCount\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a=\n\x0f\x43omponentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xe8\t\n\nForexEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12#\n\rbase_currency\x18\x07 \x01(\tR\x0c\x62\x61seCurrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12\\\n\x07mapping\x18\x16 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.ForexEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12%\n\x0equote_currency\x18! \x01(\tR\rquoteCurrency\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xcd\x03\n\x0bOptionEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x61\x63tive\x18\x02 \x01(\x08R\x06\x61\x63tive\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x04 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x05 \x01(\tR\x07\x63ountry\x12\x1e\n\nunderlying\x18\x06 \x01(\tR\nunderlying\x12\x16\n\x06strike\x18\x07 \x01(\x01R\x06strike\x12)\n\x06\x65xpiry\x18\x08 \x01(\x0b\x32\x11.google.type.DateR\x06\x65xpiry\x12M\n\x0boption_type\x18\t \x01(\x0e\x32,.systemathics.apis.type.shared.v1.OptionTypeR\noptionType\x12\\\n\rexercise_type\x18\n \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.ExerciseTypeR\x0c\x65xerciseType\"\xae\x1d\n\tBondEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x41\n\rsecurity_type\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0csecurityType\x12\x1f\n\x0blisted_mics\x18\x03 \x03(\tR\nlistedMics\x12\x30\n\x04isin\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04isin\x12\x30\n\x04name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04name\x12\x36\n\x07\x63ountry\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07\x63ountry\x12\x38\n\x08\x63urrency\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63urrency\x12\x34\n\x06ticker\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06ticker\x12X\n\x19market_sector_description\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x17marketSectorDescription\x12\x30\n\x04\x66igi\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04\x66igi\x12O\n\x14security_description\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x13securityDescription\x12>\n\x0bparsekyable\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bparsekyable\x12\x32\n\x05\x63usip\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x63usip\x12\x32\n\x05sedol\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sedol\x12\x41\n\rmarket_status\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cmarketStatus\x12\x44\n\x0e\x63lassification\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0e\x63lassification\x12R\n\x16previous_closing_value\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x14previousClosingValue\x12\x45\n\x15previous_trading_date\x18\x12 \x01(\x0b\x32\x11.google.type.DateR\x13previousTradingDate\x12K\n\x16trading_day_start_time\x18\x13 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x13tradingDayStartTime\x12G\n\x14trading_day_end_time\x18\x14 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x11tradingDayEndTime\x12-\n\x08maturity\x18\x15 \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12\x65\n\x10\x63oupon_frequency\x18\x16 \x01(\x0e\x32:.systemathics.apis.services.static_data.v1.CouponFrequencyR\x0f\x63ouponFrequency\x12=\n\x0b\x63oupon_type\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\ncouponType\x12\x34\n\x06\x63oupon\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x06\x63oupon\x12\x41\n\ramount_issued\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0c\x61mountIssued\x12?\n\x0cpayment_rank\x18\x1a \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bpaymentRank\x12;\n\npar_amount\x18\x1b \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\tparAmount\x12P\n\tday_count\x18\x1c \x01(\x0e\x32\x33.systemathics.apis.services.static_data.v1.DayCountR\x08\x64\x61yCount\x12[\n\x1b\x63lassification_level_4_name\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x18\x63lassificationLevel4Name\x12=\n\x0b\x66\x61\x63\x65_amount\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\nfaceAmount\x12\x7f\n/price_display_format_minimum_number_of_decimals\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR)priceDisplayFormatMinimumNumberOfDecimals\x12\x45\n\x15security_pricing_date\x18  \x01(\x0b\x32\x11.google.type.DateR\x13securityPricingDate\x12H\n\x16\x63\x61lculational_maturity\x18! \x01(\x0b\x32\x11.google.type.DateR\x15\x63\x61lculationalMaturity\x12K\n\x12\x62usiness_structure\x18\" \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11\x62usinessStructure\x12\x45\n\x0findustry_sector\x18# \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0eindustrySector\x12\x43\n\x0eindustry_group\x18$ \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rindustryGroup\x12I\n\x11industry_subgroup\x18% \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x10industrySubgroup\x12\x62\n\x1eposition_multiplication_factor\x18& \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x1cpositionMultiplicationFactor\x12K\n\x12\x61mount_outstanding\x18\' \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x11\x61mountOutstanding\x12I\n\x11minimum_increment\x18( \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x10minimumIncrement\x12T\n\x17normalized_payment_rank\x18) \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x15normalizedPaymentRank\x12\x45\n\x0f\x63ollateral_type\x18* \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0e\x63ollateralType\x12\x41\n\rmaturity_type\x18+ \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cmaturityType\x12\x41\n\roffering_type\x18, \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cofferingType\x12^\n\x1cregulatory_registration_type\x18- \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x1aregulatoryRegistrationType\x12\x63\n\x1f\x63\x61pital_structure_equity_ticker\x18. \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x1c\x63\x61pitalStructureEquityTicker\x12U\n\x18ultimate_country_of_risk\x18/ \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x15ultimateCountryOfRisk\x12\x37\n\x0enext_call_date\x18\x30 \x01(\x0b\x32\x11.google.type.DateR\x0cnextCallDate\x12\x34\n\x06issuer\x18\x31 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06issuer\x12\x30\n\nissue_date\x18\x32 \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12=\n\x0bissue_price\x18\x33 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\nissuePrice\x12\x43\n\x0e\x66loater_spread\x18\x34 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\rfloaterSpread\x12T\n\x17\x64iscovery_source_ticker\x18\x35 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x15\x64iscoverySourceTicker\"\xed\x06\n\rCdsIndexEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x1a\n\x08\x63urrency\x18\x04 \x01(\tR\x08\x63urrency\x12+\n\x11payment_frequency\x18\x05 \x01(\tR\x10paymentFrequency\x12\x38\n\x0e\x65\x66\x66\x65\x63tive_date\x18\x06 \x01(\x0b\x32\x11.google.type.DateR\reffectiveDate\x12\x30\n\nannex_date\x18\x07 \x01(\x0b\x32\x11.google.type.DateR\tannexDate\x12\x14\n\x05tenor\x18\x08 \x01(\tR\x05tenor\x12-\n\x08maturity\x18\t \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12\x16\n\x06\x66\x61mily\x18\n \x01(\tR\x06\x66\x61mily\x12\x1d\n\nsub_family\x18\x0b \x01(\tR\tsubFamily\x12\x16\n\x06series\x18\x0c \x01(\x05R\x06series\x12\x18\n\x07version\x18\r \x01(\x05R\x07version\x12\x41\n\x13version_first_dates\x18\x0e \x03(\x0b\x32\x11.google.type.DateR\x11versionFirstDates\x12+\n\x12\x63\x64s_red_pair_codes\x18\x0f \x03(\tR\x0f\x63\x64sRedPairCodes\x12#\n\rrecovery_rate\x18\x10 \x01(\x01R\x0crecoveryRate\x12?\n\x12\x66irst_payment_date\x18\x11 \x01(\x0b\x32\x11.google.type.DateR\x10\x66irstPaymentDate\x12\x1c\n\non_the_run\x18\x12 \x01(\x08R\x08onTheRun\x12\"\n\x0c\x63onstituents\x18\x13 \x03(\tR\x0c\x63onstituents\x12\x35\n\x16\x64\x65\x66\x61ulted_constituents\x18\x14 \x03(\tR\x15\x64\x65\x66\x61ultedConstituents\x12\x18\n\x07\x66\x61\x63tors\x18\x15 \x03(\x01R\x07\x66\x61\x63tors\x12\x16\n\x06\x63oupon\x18\x16 \x01(\x01R\x06\x63oupon\"\xa2\x04\n\x14\x43\x64sIndexTrancheEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x03 \x01(\tR\x08\x63urrency\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12(\n\x10\x63\x64s_company_name\x18\x05 \x01(\tR\x0e\x63\x64sCompanyName\x12P\n\tday_count\x18\x06 \x01(\x0e\x32\x33.systemathics.apis.services.static_data.v1.DayCountR\x08\x64\x61yCount\x12\x14\n\x05tenor\x18\x07 \x01(\x01R\x05tenor\x12-\n\x08maturity\x18\x08 \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12#\n\rsecurity_type\x18\t \x01(\tR\x0csecurityType\x12\x1c\n\nfeed_eid_4\x18\n \x01(\tR\x08\x66\x65\x65\x64\x45id4\x12 \n\x0c\x63\x64s_index_id\x18\x0b \x01(\tR\ncdsIndexId\x12!\n\x0c\x61ttach_point\x18\x0c \x01(\x01R\x0b\x61ttachPoint\x12!\n\x0c\x64\x65tach_point\x18\r \x01(\x01R\x0b\x64\x65tachPoint\"\x8d\x0b\n\x08\x43\x64sEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12Z\n\x07mapping\x18\x16 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.CdsEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12-\n\x08maturity\x18\" \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12V\n\tfrequency\x18# \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12\x14\n\x05tenor\x18$ \x01(\tR\x05tenor\x12\x1a\n\x08recovery\x18% \x01(\x01R\x08recovery\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"4\n\x08TickSize\x12\x14\n\x05price\x18\x01 \x01(\x01R\x05price\x12\x12\n\x04tick\x18\x02 \x01(\x01R\x04tick\"\xe2\x01\n\x12\x41nalystPerformance\x12\x1b\n\tfirm_name\x18\x01 \x01(\tR\x08\x66irmName\x12!\n\x0c\x61nalyst_name\x18\x02 \x01(\tR\x0b\x61nalystName\x12\x18\n\x07ranking\x18\x03 \x01(\tR\x07ranking\x12#\n\rtotal_returns\x18\x04 \x01(\x01R\x0ctotalReturns\x12&\n\x0erecommendation\x18\x05 \x01(\tR\x0erecommendation\x12%\n\x04\x64\x61te\x18\x06 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\"\xf8\x02\n\x19\x42\x65stAnalystRecommendation\x12\x1b\n\tfirm_name\x18\x01 \x01(\tR\x08\x66irmName\x12\x18\n\x07\x61nalyst\x18\x02 \x01(\tR\x07\x61nalyst\x12&\n\x0erecommendation\x18\x03 \x01(\tR\x0erecommendation\x12\x16\n\x06rating\x18\x04 \x01(\x05R\x06rating\x12\x1f\n\x0b\x61\x63tion_code\x18\x05 \x01(\tR\nactionCode\x12!\n\x0ctarget_price\x18\x06 \x01(\x01R\x0btargetPrice\x12\x16\n\x06period\x18\x07 \x01(\tR\x06period\x12%\n\x04\x64\x61te\x18\x08 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x39\n\x19\x62\x65st_analyst_rankink_rank\x18\t \x01(\x05R\x16\x62\x65stAnalystRankinkRank\x12&\n\x0fone_year_return\x18\n \x01(\x01R\roneYearReturn\"\x91\x02\n\x14\x45\x61rningsAnnouncement\x12\x1f\n\x0byear_period\x18\x01 \x01(\tR\nyearPeriod\x12>\n\x11\x61nnouncement_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x10\x61nnouncementDate\x12+\n\x11\x61nnouncement_time\x18\x03 \x01(\tR\x10\x61nnouncementTime\x12!\n\x0c\x65\x61rnings_eps\x18\x04 \x01(\x01R\x0b\x65\x61rningsEps\x12%\n\x0e\x63omparable_eps\x18\x05 \x01(\x01R\rcomparableEps\x12!\n\x0c\x65stimate_eps\x18\x06 \x01(\x01R\x0b\x65stimateEps\"\xd5\x02\n\x08\x44ividend\x12\x36\n\rdeclared_date\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x0c\x64\x65\x63laredDate\x12*\n\x07\x65x_date\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x06\x65xDate\x12\x32\n\x0brecord_date\x18\x03 \x01(\x0b\x32\x11.google.type.DateR\nrecordDate\x12\x34\n\x0cpayable_date\x18\x04 \x01(\x0b\x32\x11.google.type.DateR\x0bpayableDate\x12\'\n\x0f\x64ividend_amount\x18\x05 \x01(\x01R\x0e\x64ividendAmount\x12-\n\x12\x64ividend_frequency\x18\x06 \x01(\tR\x11\x64ividendFrequency\x12#\n\rdividend_type\x18\x07 \x01(\tR\x0c\x64ividendType\"\xf7\x02\n\x06Holder\x12\x1f\n\x0bholder_name\x18\x01 \x01(\tR\nholderName\x12%\n\x0eportfolio_name\x18\x02 \x01(\tR\rportfolioName\x12\x16\n\x06source\x18\x03 \x01(\tR\x06source\x12\x1f\n\x0b\x61mount_held\x18\x04 \x01(\x01R\namountHeld\x12/\n\x13percent_outstanding\x18\x05 \x01(\x01R\x12percentOutstanding\x12#\n\rlatest_change\x18\x06 \x01(\x01R\x0clatestChange\x12\x32\n\x0b\x66iling_date\x18\x07 \x01(\x0b\x32\x11.google.type.DateR\nfilingDate\x12)\n\x10institution_type\x18\x08 \x01(\tR\x0finstitutionType\x12\x18\n\x07\x63ountry\x18\t \x01(\tR\x07\x63ountry\x12\x1d\n\nmetro_area\x18\n \x01(\tR\tmetroArea*\x86\x02\n\rFrequencyType\x12\x1e\n\x1a\x46REQUENCY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46REQUENCY_TYPE_NONE\x10\x01\x12\x16\n\x12\x46REQUENCY_TYPE_DAY\x10\x02\x12\x17\n\x13\x46REQUENCY_TYPE_WEEK\x10\x03\x12\x18\n\x14\x46REQUENCY_TYPE_MONTH\x10\x04\x12\x1a\n\x16\x46REQUENCY_TYPE_QUARTER\x10\x05\x12\x1d\n\x19\x46REQUENCY_TYPE_SEMIANNUAL\x10\x06\x12\x19\n\x15\x46REQUENCY_TYPE_ANNUAL\x10\x07\x12\x1b\n\x17\x46REQUENCY_TYPE_BIANNUAL\x10\x08*\x81\x01\n\x0c\x45xerciseType\x12\x1d\n\x19\x45XERCISE_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45XERCISE_TYPE_AMERICAN\x10\x01\x12\x1a\n\x16\x45XERCISE_TYPE_EUROPEAN\x10\x02\x12\x1a\n\x16\x45XERCISE_TYPE_BERMUDAN\x10\x03*\xed\x01\n\x0f\x43ouponFrequency\x12 \n\x1c\x43OUPON_FREQUENCY_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43OUPON_FREQUENCY_ANNUAL\x10\x01\x12 \n\x1c\x43OUPON_FREQUENCY_SEMI_ANNUAL\x10\x02\x12\x1d\n\x19\x43OUPON_FREQUENCY_QUATERLY\x10\x04\x12\x1f\n\x1b\x43OUPON_FREQUENCY_BI_MONTHLY\x10\x06\x12\x1c\n\x18\x43OUPON_FREQUENCY_MONTHLY\x10\x0c\x12\x1b\n\x17\x43OUPON_FREQUENCY_WEEKLY\x10\x34*\xe1\x10\n\x08\x44\x61yCount\x12\x19\n\x15\x44\x41Y_COUNT_UNSPECIFIED\x10\x00\x12\x15\n\x11\x44\x41Y_COUNT_ACT_ACT\x10\x01\x12\x15\n\x11\x44\x41Y_COUNT_ACT_360\x10\x02\x12\x15\n\x11\x44\x41Y_COUNT_ACT_365\x10\x03\x12\x14\n\x10\x44\x41Y_COUNT_30_ACT\x10\x04\x12\x14\n\x10\x44\x41Y_COUNT_30_360\x10\x05\x12\x14\n\x10\x44\x41Y_COUNT_30_365\x10\x06\x12\x14\n\x10\x44\x41Y_COUNT_NL_ACT\x10\x07\x12\x14\n\x10\x44\x41Y_COUNT_NL_360\x10\x08\x12\x14\n\x10\x44\x41Y_COUNT_NL_365\x10\t\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_ACT_NON_EOM\x10\n\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_360_NON_EOM\x10\x0b\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_365_NON_EOM\x10\x0c\x12\x1c\n\x18\x44\x41Y_COUNT_30_ACT_NON_EOM\x10\r\x12\x1c\n\x18\x44\x41Y_COUNT_30_360_NON_EOM\x10\x0e\x12\x1c\n\x18\x44\x41Y_COUNT_30_365_NON_EOM\x10\x0f\x12\x1c\n\x18\x44\x41Y_COUNT_NL_ACT_NON_EOM\x10\x10\x12\x1c\n\x18\x44\x41Y_COUNT_NL_360_NON_EOM\x10\x11\x12\x1c\n\x18\x44\x41Y_COUNT_NL_365_NON_EOM\x10\x12\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_ACT\x10\x13\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_360\x10\x14\x12\x19\n\x15\x44\x41Y_COUNT_ISMA_30_365\x10\x15\x12 \n\x1c\x44\x41Y_COUNT_ISMA30_ACT_NON_EOM\x10\x16\x12 \n\x1c\x44\x41Y_COUNT_ISMA_30_360_NONEOM\x10\x17\x12 \n\x1c\x44\x41Y_COUNT_ISMA30_365_NON_EOM\x10\x18\x12\x15\n\x11\x44\x41Y_COUNT_ACT_364\x10\x1b\x12\x18\n\x14\x44\x41Y_COUNT_ACT_365_66\x10\x1c\x12\x1c\n\x18\x44\x41Y_COUNT_US_MUNI_30_360\x10\x1d\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_364_NON_EOM\x10\x1e\x12 \n\x1c\x44\x41Y_COUNT_MUNI30_360_NON_EOM\x10 \x12\x1a\n\x16\x44\x41Y_COUNT_BUS_DAYS_252\x10!\x12\x1b\n\x17\x44\x41Y_COUNT_GERMAN_30_360\x10#\x12 \n\x1c\x44\x41Y_COUNT_BUS_DAY_252NON_EOM\x10$\x12 \n\x1c\x44\x41Y_COUNT_ACT_365_66_NON_EOM\x10%\x12 \n\x1c\x44\x41Y_COUNT_GER_30_360_NON_EOM\x10&\x12\x1c\n\x18\x44\x41Y_COUNT_US_WIT_ACT_ACT\x10(\x12\x1c\n\x18\x44\x41Y_COUNT_US_WIB_ACT_360\x10)\x12\x1f\n\x1b\x44\x41Y_COUNT_ISDA_SWAPS_30_360\x10,\x12\x1f\n\x1b\x44\x41Y_COUNT_ISDA_SWAPS_30_365\x10-\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_360_NON_EOM\x10/\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_365_NON_EOM\x10\x30\x12 \n\x1c\x44\x41Y_COUNT_ISDA30_ACT_NON_EOM\x10\x31\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_360\x10\x32\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_365\x10\x33\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_30E_ACT\x10\x34\x12 \n\x1c\x44\x41Y_COUNT_ISDA_30E_360_N_EOM\x10\x35\x12 \n\x1c\x44\x41Y_COUNT_ISDA_30E_365_N_EOM\x10\x36\x12\x1a\n\x16\x44\x41Y_COUNT_ISDA_ACT_ACT\x10:\x12 \n\x1c\x44\x41Y_COUNT_ISDA_ACT_ACT_N_EOM\x10=\x12\x14\n\x10\x44\x41Y_COUNT_28_360\x10>\x12\x14\n\x10\x44\x41Y_COUNT_BD_252\x10\x63\x12\x19\n\x15\x44\x41Y_COUNT_ACT_ACT_101\x10\x65\x12\x19\n\x15\x44\x41Y_COUNT_ACT_360_102\x10\x66\x12\x19\n\x15\x44\x41Y_COUNT_ACT_365_103\x10g\x12\x18\n\x14\x44\x41Y_COUNT_30_360_104\x10h\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_ACT_NOM_105\x10i\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_360_NOM_106\x10j\x12\x1d\n\x19\x44\x41Y_COUNT_ACT_365_NOM_107\x10k\x12\x1e\n\x19\x44\x41Y_COUNT_ISMA_30_360_131\x10\x83\x01\x12\x1f\n\x1a\x44\x41Y_COUNT_ISDA_ACT_ACT_201\x10\xc9\x01\x12\x1e\n\x19\x44\x41Y_COUNT_AFB_ACT_ACT_202\x10\xca\x01\x12#\n\x1e\x44\x41Y_COUNT_ISDA_ACT_ACT_NOM_203\x10\xcb\x01\x12\"\n\x1d\x44\x41Y_COUNT_AFB_ACT_ACT_NOM_204\x10\xcc\x01\x12 \n\x1b\x44\x41Y_COUNT_ISMA_ACT_ACT__206\x10\xce\x01\x12#\n\x1e\x44\x41Y_COUNT_ISMA_ACT_ACT_NOM_207\x10\xcf\x01\x12\x1b\n\x16\x44\x41Y_COUNT_BUSINESS_252\x10\xfc\x01\x12\x16\n\x11\x44\x41Y_COUNT_30E_360\x10\xde\x07\x12\x16\n\x11\x44\x41Y_COUNT_30E_365\x10\xdf\x07\x12\x16\n\x11\x44\x41Y_COUNT_30E_ACT\x10\xe0\x07\x12\x16\n\x11\x44\x41Y_COUNT_30G_360\x10\xe1\x07\x12\x16\n\x11\x44\x41Y_COUNT_301_360\x10\xe2\x07\x12\x16\n\x11\x44\x41Y_COUNT_301_365\x10\xe3\x07\x12\x16\n\x11\x44\x41Y_COUNT_30I_ACT\x10\xe4\x07\x12\x16\n\x11\x44\x41Y_COUNT_30M_360\x10\xe5\x07*b\n\x0cSwaptionType\x12\x1d\n\x19SWAPTION_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13SWAPTION_TYPE_PAYER\x10\x01\x12\x1a\n\x16SWAPTION_TYPE_RECEIVER\x10\x02\x32\x84\x03\n\x11StaticDataService\x12\xa1\x01\n\nStaticData\x12<.systemathics.apis.services.static_data.v1.StaticDataRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/staticdata\x12\xca\x01\n\x17StaticDataByIdentifiers\x12I.systemathics.apis.services.static_data.v1.StaticDataByIdentifiersRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/staticdata_by_identifiersB\x85\x02\n-com.systemathics.apis.services.static_data.v1B\x0fStaticDataProtoP\x01\xa2\x02\x04SASS\xaa\x02(Systemathics.Apis.Services.StaticData.V1\xca\x02(Systemathics\\Apis\\Services\\StaticData\\V1\xe2\x02\x34Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\xea\x02,Systemathics::Apis::Services::StaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.static_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.systemathics.apis.services.static_data.v1B\017StaticDataProtoP\001\242\002\004SASS\252\002(Systemathics.Apis.Services.StaticData.V1\312\002(Systemathics\\Apis\\Services\\StaticData\\V1\342\0024Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\352\002,Systemathics::Apis::Services::StaticData::V1'
  _globals['_INDEXENTRY_MAPPINGENTRY']._options = None
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_INDEXENTRY_COMPONENTSENTRY']._options = None
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_options = b'8\001'
  _globals['_FOREXENTRY_MAPPINGENTRY']._options = None
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_CDSENTRY_MAPPINGENTRY']._options = None
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_STATICDATASERVICE'].methods_by_name['StaticData']._options = None
  _globals['_STATICDATASERVICE'].methods_by_name['StaticData']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/staticdata'
  _globals['_STATICDATASERVICE'].methods_by_name['StaticDataByIdentifiers']._options = None
  _globals['_STATICDATASERVICE'].methods_by_name['StaticDataByIdentifiers']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/staticdata_by_identifiers'
  _globals['_FREQUENCYTYPE']._serialized_start=27931
  _globals['_FREQUENCYTYPE']._serialized_end=28193
  _globals['_EXERCISETYPE']._serialized_start=28196
  _globals['_EXERCISETYPE']._serialized_end=28325
  _globals['_COUPONFREQUENCY']._serialized_start=28328
  _globals['_COUPONFREQUENCY']._serialized_end=28565
  _globals['_DAYCOUNT']._serialized_start=28568
  _globals['_DAYCOUNT']._serialized_end=30713
  _globals['_SWAPTIONTYPE']._serialized_start=30715
  _globals['_SWAPTIONTYPE']._serialized_end=30813
  _globals['_STATICDATAREQUEST']._serialized_start=403
  _globals['_STATICDATAREQUEST']._serialized_end=2500
  _globals['_STATICDATABYIDENTIFIERSREQUEST']._serialized_start=2503
  _globals['_STATICDATABYIDENTIFIERSREQUEST']._serialized_end=2664
  _globals['_STATICDATADATE']._serialized_start=2667
  _globals['_STATICDATADATE']._serialized_end=2823
  _globals['_STATICDATADATERANGE']._serialized_start=2826
  _globals['_STATICDATADATERANGE']._serialized_end=2965
  _globals['_STATICDATADOUBLE']._serialized_start=2968
  _globals['_STATICDATADOUBLE']._serialized_end=3109
  _globals['_STATICDATADOUBLERANGE']._serialized_start=3112
  _globals['_STATICDATADOUBLERANGE']._serialized_end=3275
  _globals['_STATICDATAINT']._serialized_start=3278
  _globals['_STATICDATAINT']._serialized_end=3413
  _globals['_STATICDATAINTRANGE']._serialized_start=3416
  _globals['_STATICDATAINTRANGE']._serialized_end=3574
  _globals['_STATICDATARESPONSE']._serialized_start=3577
  _globals['_STATICDATARESPONSE']._serialized_end=4542
  _globals['_CDSINDEXOPTIONRESPONSE']._serialized_start=4545
  _globals['_CDSINDEXOPTIONRESPONSE']._serialized_end=4690
  _globals['_CDSINDEXOPTIONENTRY']._serialized_start=4693
  _globals['_CDSINDEXOPTIONENTRY']._serialized_end=5153
  _globals['_BONDRESPONSE']._serialized_start=5155
  _globals['_BONDRESPONSE']._serialized_end=5280
  _globals['_CDSRESPONSE']._serialized_start=5282
  _globals['_CDSRESPONSE']._serialized_end=5405
  _globals['_CDSINDEXRESPONSE']._serialized_start=5408
  _globals['_CDSINDEXRESPONSE']._serialized_end=5541
  _globals['_CDSINDEXTRANCHERESPONSE']._serialized_start=5544
  _globals['_CDSINDEXTRANCHERESPONSE']._serialized_end=5691
  _globals['_EQUITYRESPONSE']._serialized_start=5694
  _globals['_EQUITYRESPONSE']._serialized_end=5823
  _globals['_ETFRESPONSE']._serialized_start=5825
  _globals['_ETFRESPONSE']._serialized_end=5948
  _globals['_FOREXRESPONSE']._serialized_start=5950
  _globals['_FOREXRESPONSE']._serialized_end=6077
  _globals['_FUTURERESPONSE']._serialized_start=6080
  _globals['_FUTURERESPONSE']._serialized_end=6209
  _globals['_INDEXRESPONSE']._serialized_start=6211
  _globals['_INDEXRESPONSE']._serialized_end=6338
  _globals['_OPTIONRESPONSE']._serialized_start=6341
  _globals['_OPTIONRESPONSE']._serialized_end=6470
  _globals['_EQUITYENTRY']._serialized_start=6473
  _globals['_EQUITYENTRY']._serialized_end=9697
  _globals['_ETFENTRY']._serialized_start=9700
  _globals['_ETFENTRY']._serialized_end=12407
  _globals['_FUTUREENTRY']._serialized_start=12410
  _globals['_FUTUREENTRY']._serialized_end=16287
  _globals['_INDEXENTRY']._serialized_start=16290
  _globals['_INDEXENTRY']._serialized_end=17931
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_start=17810
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_end=17868
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_start=17870
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_end=17931
  _globals['_FOREXENTRY']._serialized_start=17934
  _globals['_FOREXENTRY']._serialized_end=19190
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_start=17810
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_end=17868
  _globals['_OPTIONENTRY']._serialized_start=19193
  _globals['_OPTIONENTRY']._serialized_end=19654
  _globals['_BONDENTRY']._serialized_start=19657
  _globals['_BONDENTRY']._serialized_end=23415
  _globals['_CDSINDEXENTRY']._serialized_start=23418
  _globals['_CDSINDEXENTRY']._serialized_end=24295
  _globals['_CDSINDEXTRANCHEENTRY']._serialized_start=24298
  _globals['_CDSINDEXTRANCHEENTRY']._serialized_end=24844
  _globals['_CDSENTRY']._serialized_start=24847
  _globals['_CDSENTRY']._serialized_end=26268
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_start=17810
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_end=17868
  _globals['_TICKSIZE']._serialized_start=26270
  _globals['_TICKSIZE']._serialized_end=26322
  _globals['_ANALYSTPERFORMANCE']._serialized_start=26325
  _globals['_ANALYSTPERFORMANCE']._serialized_end=26551
  _globals['_BESTANALYSTRECOMMENDATION']._serialized_start=26554
  _globals['_BESTANALYSTRECOMMENDATION']._serialized_end=26930
  _globals['_EARNINGSANNOUNCEMENT']._serialized_start=26933
  _globals['_EARNINGSANNOUNCEMENT']._serialized_end=27206
  _globals['_DIVIDEND']._serialized_start=27209
  _globals['_DIVIDEND']._serialized_end=27550
  _globals['_HOLDER']._serialized_start=27553
  _globals['_HOLDER']._serialized_end=27928
  _globals['_STATICDATASERVICE']._serialized_start=30816
  _globals['_STATICDATASERVICE']._serialized_end=31204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v2/set_tick.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v2/set_tick.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xa8\x02\n\x14SetTickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x31\n\x08\x64\x61tetime\x18\x02 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12V\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x42.systemathics.apis.services.tick.v2.SetTickScalarRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xbb\x01\n\x1aSetTickScalarStreamRequest\x12\x45\n\x04info\x18\x01 \x01(\x0b\x32/.systemathics.apis.services.tick.v2.SetTickInfoH\x00R\x04info\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xba\x02\n\x14SetTickVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x31\n\x08\x64\x61tetime\x18\x02 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12V\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x42.systemathics.apis.services.tick.v2.SetTickVectorRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xbb\x01\n\x1aSetTickVectorStreamRequest\x12\x45\n\x04info\x18\x01 \x01(\x0b\x32/.systemathics.apis.services.tick.v2.SetTickInfoH\x00R\x04info\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickVectorDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xac\x01\n\x17\x44\x65leteTickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12+\n\x05\x64\x61tes\x18\x03 \x03(\x0b\x32\x15.google.type.DateTimeR\x05\x64\x61tes\"\xc2\x01\n\x17\x44\x65leteTickVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x41\n\x04keys\x18\x03 \x03(\x0b\x32-.systemathics.apis.services.tick.v2.VectorKeyR\x04keys\"s\n\x0bSetTickInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\"Z\n\x11SetTickScalarData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"P\n\tVectorKey\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"l\n\x11SetTickVectorData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta2\xc6\n\n\x0eSetTickService\x12|\n\x0fWriteTickScalar\x12\x38.systemathics.apis.services.tick.v2.SetTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_scalar\x12\x8a\x01\n\x15WriteTickScalarStream\x12>.systemathics.apis.services.tick.v2.SetTickScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_scalar(\x01\x12|\n\x0fWriteTickVector\x12\x38.systemathics.apis.services.tick.v2.SetTickVectorRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_vector\x12\x8a\x01\n\x15WriteTickVectorStream\x12>.systemathics.apis.services.tick.v2.SetTickVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/v2/tick_vector(\x01\x12}\n\x10UpdateTickScalar\x12\x38.systemathics.apis.services.tick.v2.SetTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_scalar\x12\x8b\x01\n\x16UpdateTickScalarStream\x12>.systemathics.apis.services.tick.v2.SetTickScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_scalar(\x01\x12}\n\x10UpdateTickVector\x12\x38.systemathics.apis.services.tick.v2.SetTickVectorRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_vector\x12\x8b\x01\n\x16UpdateTickVectorStream\x12>.systemathics.apis.services.tick.v2.SetTickVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\x1a\x0f/v2/tick_vector(\x01\x12\x80\x01\n\x10\x44\x65leteTickScalar\x12;.systemathics.apis.services.tick.v2.DeleteTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11*\x0f/v2/tick_scalar\x12\x80\x01\n\x10\x44\x65leteTickVector\x12;.systemathics.apis.services.tick.v2.DeleteTickVectorRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11*\x0f/v2/tick_vectorB\xe3\x01\n&com.systemathics.apis.services.tick.v2B\x0cSetTickProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.set_tick_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\014SetTickProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._options = None
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._options = None
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalar']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalar']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalarStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickScalarStream']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVector']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVector']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVectorStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['WriteTickVectorStream']._serialized_options = b'\202\323\344\223\002\021\"\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalar']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalar']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalarStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickScalarStream']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVector']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVector']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVectorStream']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['UpdateTickVectorStream']._serialized_options = b'\202\323\344\223\002\021\032\017/v2/tick_vector'
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickScalar']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickScalar']._serialized_options = b'\202\323\344\223\002\021*\017/v2/tick_scalar'
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickVector']._options = None
  _globals['_SETTICKSERVICE'].methods_by_name['DeleteTickVector']._serialized_options = b'\202\323\344\223\002\021*\017/v2/tick_vector'
  _globals['_SETTICKSCALARREQUEST']._serialized_start=410
  _globals['_SETTICKSCALARREQUEST']._serialized_end=706
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._serialized_start=651
  _globals['_SETTICKSCALARREQUEST_DATAENTRY']._serialized_end=706
  _globals['_SETTICKSCALARSTREAMREQUEST']._serialized_start=709
  _globals['_SETTICKSCALARSTREAMREQUEST']._serialized_end=896
  _globals['_SETTICKVECTORREQUEST']._serialized_start=899
  _globals['_SETTICKVECTORREQUEST']._serialized_end=1213
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._serialized_start=651
  _globals['_SETTICKVECTORREQUEST_DATAENTRY']._serialized_end=706
  _globals['_SETTICKVECTORSTREAMREQUEST']._serialized_start=1216
  _globals['_SETTICKVECTORSTREAMREQUEST']._serialized_end=1403
  _globals['_DELETETICKSCALARREQUEST']._serialized_start=1406
  _globals['_DELETETICKSCALARREQUEST']._serialized_end=1578
  _globals['_DELETETICKVECTORREQUEST']._serialized_start=1581
  _globals['_DELETETICKVECTORREQUEST']._serialized_end=1775
  _globals['_SETTICKINFO']._serialized_start=1777
  _globals['_SETTICKINFO']._serialized_end=1892
  _globals['_SETTICKSCALARDATA']._serialized_start=1894
  _globals['_SETTICKSCALARDATA']._serialized_end=1984
  _globals['_VECTORKEY']._serialized_start=1986
  _globals['_VECTORKEY']._serialized_end=2066
  _globals['_SETTICKVECTORDATA']._serialized_start=2068
  _globals['_SETTICKVECTORDATA']._serialized_end=2176
  _globals['_SETTICKSERVICE']._serialized_start=2179
  _globals['_SETTICKSERVICE']._serialized_end=3529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v2/set_data_mode.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/type/shared/v2/set_data_mode.proto\x12 systemathics.apis.type.shared.v2*|\n\x0bSetDataMode\x12\x1d\n\x19SET_DATA_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13SET_DATA_MODE_WRITE\x10\x01\x12\x18\n\x14SET_DATA_MODE_APPEND\x10\x02\x12\x1b\n\x17SET_DATA_MODE_OVERWRITE\x10\x03\x42\xdd\x01\n$com.systemathics.apis.type.shared.v2B\x10SetDataModeProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V2\xca\x02 Systemathics\\Apis\\Type\\Shared\\V2\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v2.set_data_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v2B\020SetDataModeProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V2\312\002 Systemathics\\Apis\\Type\\Shared\\V2\342\002,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V2'
  _globals['_SETDATAMODE']._serialized_start=90
  _globals['_SETDATAMODE']._serialized_end=214
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.daily.v2 import set_daily_scalar_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__scalar__pb2


class SetDailyScalarServiceStub(object):
    """Called to set daily prices data and clear. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetDailyScalar = channel.stream_unary(
                '/systemathics.apis.services.daily.v2.SetDailyScalarService/SetDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__scalar__pb2.SetDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ClearDailyScalar = channel.unary_unary(
                '/systemathics.apis.services.daily.v2.SetDailyScalarService/ClearDailyScalar',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__scalar__pb2.ClearDailyScalarRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class SetDailyScalarServiceServicer(object):
    """Called to set daily prices data and clear. 
    """

    def SetDailyScalar(self, request_iterator, context):
        """Sets daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearDailyScalar(self, request, context):
        """Delete daily scalar timeseries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SetDailyScalarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetDailyScalar': grpc.stream_unary_rpc_method_handler(
                    servicer.SetDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__scalar__pb2.SetDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ClearDailyScalar': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearDailyScalar,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__scalar__pb2.ClearDailyScalarRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v2.SetDailyScalarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SetDailyScalarService(object):
    """Called to set daily prices data and clear. 
    """

    @staticmethod
    def SetDailyScalar(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/systemathics.apis.services.daily.v2.SetDailyScalarService/SetDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__scalar__pb2.SetDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearDailyScalar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v2.SetDailyScalarService/ClearDailyScalar',
            systemathics_dot_apis_dot_services_dot_daily_dot_v2_dot_set__daily__scalar__pb2.ClearDailyScalarRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v2/set_daily.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3systemathics/apis/services/daily/v2/set_daily.proto\x12#systemathics.apis.services.daily.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\x9f\x02\n\x15SetDailyScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12X\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x44.systemathics.apis.services.daily.v2.SetDailyScalarRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xc0\x01\n\x1bSetDailyScalarStreamRequest\x12G\n\x04info\x18\x01 \x01(\x0b\x32\x31.systemathics.apis.services.daily.v2.SetDailyInfoH\x00R\x04info\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.systemathics.apis.services.daily.v2.SetDailyScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xb1\x02\n\x15SetDailyVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12%\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12X\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x44.systemathics.apis.services.daily.v2.SetDailyVectorRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xc0\x01\n\x1bSetDailyVectorStreamRequest\x12G\n\x04info\x18\x01 \x01(\x0b\x32\x31.systemathics.apis.services.daily.v2.SetDailyInfoH\x00R\x04info\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.systemathics.apis.services.daily.v2.SetDailyVectorDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xa9\x01\n\x18\x44\x65leteDailyScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\'\n\x05\x64\x61tes\x18\x03 \x03(\x0b\x32\x11.google.type.DateR\x05\x64\x61tes\"\xc4\x01\n\x18\x44\x65leteDailyVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x42\n\x04keys\x18\x03 \x03(\x0b\x32..systemathics.apis.services.daily.v2.VectorKeyR\x04keys\"t\n\x0cSetDailyInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\"O\n\x12SetDailyScalarData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"D\n\tVectorKey\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"a\n\x12SetDailyVectorData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta2\xf3\n\n\x0fSetDailyService\x12\x80\x01\n\x10WriteDailyScalar\x12:.systemathics.apis.services.daily.v2.SetDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_scalar\x12\x8e\x01\n\x16WriteDailyScalarStream\x12@.systemathics.apis.services.daily.v2.SetDailyScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_scalar(\x01\x12\x80\x01\n\x10WriteDailyVector\x12:.systemathics.apis.services.daily.v2.SetDailyVectorRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_vector\x12\x8e\x01\n\x16WriteDailyVectorStream\x12@.systemathics.apis.services.daily.v2.SetDailyVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/v2/daily_vector(\x01\x12\x81\x01\n\x11UpdateDailyScalar\x12:.systemathics.apis.services.daily.v2.SetDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_scalar\x12\x8f\x01\n\x17UpdateDailyScalarStream\x12@.systemathics.apis.services.daily.v2.SetDailyScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_scalar(\x01\x12\x81\x01\n\x11UpdateDailyVector\x12:.systemathics.apis.services.daily.v2.SetDailyVectorRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_vector\x12\x8f\x01\n\x17UpdateDailyVectorStream\x12@.systemathics.apis.services.daily.v2.SetDailyVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\x1a\x10/v2/daily_vector(\x01\x12\x84\x01\n\x11\x44\x65leteDailyScalar\x12=.systemathics.apis.services.daily.v2.DeleteDailyScalarRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12*\x10/v2/daily_scalar\x12\x84\x01\n\x11\x44\x65leteDailyVector\x12=.systemathics.apis.services.daily.v2.DeleteDailyVectorRequest\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12*\x10/v2/daily_vectorB\xe9\x01\n\'com.systemathics.apis.services.daily.v2B\rSetDailyProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V2\xca\x02#Systemathics\\Apis\\Services\\Daily\\V2\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v2.set_daily_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v2B\rSetDailyProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V2\312\002#Systemathics\\Apis\\Services\\Daily\\V2\342\002/Systemathics\\Apis\\Services\\Daily\\V2\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V2'
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._options = None
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._options = None
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalar']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalar']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalarStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyScalarStream']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVector']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVector']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVectorStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['WriteDailyVectorStream']._serialized_options = b'\202\323\344\223\002\022\"\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalar']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalar']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalarStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyScalarStream']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVector']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVector']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVectorStream']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['UpdateDailyVectorStream']._serialized_options = b'\202\323\344\223\002\022\032\020/v2/daily_vector'
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyScalar']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyScalar']._serialized_options = b'\202\323\344\223\002\022*\020/v2/daily_scalar'
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyVector']._options = None
  _globals['_SETDAILYSERVICE'].methods_by_name['DeleteDailyVector']._serialized_options = b'\202\323\344\223\002\022*\020/v2/daily_vector'
  _globals['_SETDAILYSCALARREQUEST']._serialized_start=409
  _globals['_SETDAILYSCALARREQUEST']._serialized_end=696
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._serialized_start=641
  _globals['_SETDAILYSCALARREQUEST_DATAENTRY']._serialized_end=696
  _globals['_SETDAILYSCALARSTREAMREQUEST']._serialized_start=699
  _globals['_SETDAILYSCALARSTREAMREQUEST']._serialized_end=891
  _globals['_SETDAILYVECTORREQUEST']._serialized_start=894
  _globals['_SETDAILYVECTORREQUEST']._serialized_end=1199
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._serialized_start=641
  _globals['_SETDAILYVECTORREQUEST_DATAENTRY']._serialized_end=696
  _globals['_SETDAILYVECTORSTREAMREQUEST']._serialized_start=1202
  _globals['_SETDAILYVECTORSTREAMREQUEST']._serialized_end=1394
  _globals['_DELETEDAILYSCALARREQUEST']._serialized_start=1397
  _globals['_DELETEDAILYSCALARREQUEST']._serialized_end=1566
  _globals['_DELETEDAILYVECTORREQUEST']._serialized_start=1569
  _globals['_DELETEDAILYVECTORREQUEST']._serialized_end=1765
  _globals['_SETDAILYINFO']._serialized_start=1767
  _globals['_SETDAILYINFO']._serialized_end=1883
  _globals['_SETDAILYSCALARDATA']._serialized_start=1885
  _globals['_SETDAILYSCALARDATA']._serialized_end=1964
  _globals['_VECTORKEY']._serialized_start=1966
  _globals['_VECTORKEY']._serialized_end=2034
  _globals['_SETDAILYVECTORDATA']._serialized_start=2036
  _globals['_SETDAILYVECTORDATA']._serialized_end=2133
  _globals['_SETDAILYSERVICE']._serialized_start=2136
  _globals['_SETDAILYSERVICE']._serialized_end=3531
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/filter.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-systemathics/apis/type/shared/v1/filter.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/api/field_behavior.proto\"\x97\x01\n\nDateFilter\x12/\n\x05\x65xact\x18\x01 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01H\x00R\x05\x65xact\x12O\n\x05range\x18\x02 \x01(\x0b\x32\x31.systemathics.apis.type.shared.v1.DateFilterRangeB\x04\xe2\x41\x01\x01H\x00R\x05rangeB\x07\n\x05oneof\"\x93\x01\n\x0f\x44\x61teFilterRange\x12\x34\n\tless_than\x18\x01 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01R\x08lessThan\x12J\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x11.google.type.DateB\x04\xe2\x41\x01\x01R\x12greaterOrEqualThan\"\x88\x01\n\x0c\x44oubleFilter\x12\x1c\n\x05\x65xact\x18\x01 \x01(\x01\x42\x04\xe2\x41\x01\x01H\x00R\x05\x65xact\x12Q\n\x05range\x18\x02 \x01(\x0b\x32\x33.systemathics.apis.type.shared.v1.DoubleFilterRangeB\x04\xe2\x41\x01\x01H\x00R\x05rangeB\x07\n\x05oneof\"\xab\x01\n\x11\x44oubleFilterRange\x12?\n\tless_than\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x04\xe2\x41\x01\x01R\x08lessThan\x12U\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x04\xe2\x41\x01\x01R\x12greaterOrEqualThan\"\x82\x01\n\tIntFilter\x12\x1c\n\x05\x65xact\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x01H\x00R\x05\x65xact\x12N\n\x05range\x18\x02 \x01(\x0b\x32\x30.systemathics.apis.type.shared.v1.IntFilterRangeB\x04\xe2\x41\x01\x01H\x00R\x05rangeB\x07\n\x05oneof\"\xa6\x01\n\x0eIntFilterRange\x12>\n\tless_than\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xe2\x41\x01\x01R\x08lessThan\x12T\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x04\xe2\x41\x01\x01R\x12greaterOrEqualThanB\xd8\x01\n$com.systemathics.apis.type.shared.v1B\x0b\x46ilterProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\013FilterProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_DATEFILTER'].fields_by_name['exact']._options = None
  _globals['_DATEFILTER'].fields_by_name['exact']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTER'].fields_by_name['range']._options = None
  _globals['_DATEFILTER'].fields_by_name['range']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTERRANGE'].fields_by_name['less_than']._options = None
  _globals['_DATEFILTERRANGE'].fields_by_name['less_than']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTERRANGE'].fields_by_name['greater_or_equal_than']._options = None
  _globals['_DATEFILTERRANGE'].fields_by_name['greater_or_equal_than']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTER'].fields_by_name['exact']._options = None
  _globals['_DOUBLEFILTER'].fields_by_name['exact']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTER'].fields_by_name['range']._options = None
  _globals['_DOUBLEFILTER'].fields_by_name['range']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['less_than']._options = None
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['less_than']._serialized_options = b'\342A\001\001'
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['greater_or_equal_than']._options = None
  _globals['_DOUBLEFILTERRANGE'].fields_by_name['greater_or_equal_than']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTER'].fields_by_name['exact']._options = None
  _globals['_INTFILTER'].fields_by_name['exact']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTER'].fields_by_name['range']._options = None
  _globals['_INTFILTER'].fields_by_name['range']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTERRANGE'].fields_by_name['less_than']._options = None
  _globals['_INTFILTERRANGE'].fields_by_name['less_than']._serialized_options = b'\342A\001\001'
  _globals['_INTFILTERRANGE'].fields_by_name['greater_or_equal_than']._options = None
  _globals['_INTFILTERRANGE'].fields_by_name['greater_or_equal_than']._serialized_options = b'\342A\001\001'
  _globals['_DATEFILTER']._serialized_start=173
  _globals['_DATEFILTER']._serialized_end=324
  _globals['_DATEFILTERRANGE']._serialized_start=327
  _globals['_DATEFILTERRANGE']._serialized_end=474
  _globals['_DOUBLEFILTER']._serialized_start=477
  _globals['_DOUBLEFILTER']._serialized_end=613
  _globals['_DOUBLEFILTERRANGE']._serialized_start=616
  _globals['_DOUBLEFILTERRANGE']._serialized_end=787
  _globals['_INTFILTER']._serialized_start=790
  _globals['_INTFILTER']._serialized_end=920
  _globals['_INTFILTERRANGE']._serialized_start=923
  _globals['_INTFILTERRANGE']._serialized_end=1089
# @@protoc_insertion_point(module_scope)
